==> yet_another_industrialization-1.0.2-1.21.1.jar: assets/yet_another_industrialization/yai_guidebook/machines/arboreous_greenhouse.md <==
---
navigation:
  title: "Arboreous Greenhouse"
  icon: "yet_another_industrialization:arboreous_greenhouse"
  position: 0
  parent: yet_another_industrialization:machines.md
item_ids:
  - yet_another_industrialization:arboreous_greenhouse
  - yet_another_industrialization:nutrient_rich_water_bucket
  - yet_another_industrialization:nutrient_rich_lava_bucket
  - yet_another_industrialization:dragon_breath_bucket
  - yet_another_industrialization:nutrient_rich_dragon_breath_bucket
---

# Arboreous Greenhouse
###### *Crane's law attacks once again*

<GameScene zoom="2" interactive={true} fullWidth={true}>
    <MultiblockShape controller="yet_another_industrialization:arboreous_greenhouse" />
</GameScene>

Arboreous Greenhouses are capable of growing trees or otherwise large plants.

AAAAAAAAAAAAA RECIPE

## Getting started

All recipes require a single sapling (or equivalent), a fluid and the appropriate multiblock soil.

Which ones? Well, different plants naturally have different needs. Some might need Water and Sand while others require Lava and Netherrack. Always check your recipe viewer for accurate info!

Trees will always yield their Leaves and Logs and sometimes their fruit/equivalent drop.

## Better yields

All outputs can be doubled by replacing the fluid used with its nutrient variant. Using a **Centrifuge**, mix the following:

Water + Bone Meal = **Nutrient Water**

Lava + Nether Wart = **Nutrient Lava**

Dragon Breath + Popped Chorus Fruit = **Nutrient Dragon Breath**

Dragon Breath is annoying to collect, so consider automating it through [Impure Dragon Breath purification](../generators/dragon_egg_energy_siphon.md)!

==> yet_another_industrialization-1.1.0-1.21.1.jar: assets/yet_another_industrialization/yai_guidebook/machines/arboreous_greenhouse.md <==
---
navigation:
  title: "Arboreous Greenhouse"
  icon: "yet_another_industrialization:arboreous_greenhouse"
  position: 0
  parent: yet_another_industrialization:machines.md
item_ids:
  - yet_another_industrialization:arboreous_greenhouse
  - yet_another_industrialization:nutrient_rich_water_bucket
  - yet_another_industrialization:nutrient_rich_lava_bucket
  - yet_another_industrialization:dragon_breath_bucket
  - yet_another_industrialization:nutrient_rich_dragon_breath_bucket
---

# Arboreous Greenhouse
###### *letitgrowleitgrow*

<GameScene zoom="2" interactive={true} fullWidth={true}>
    <MultiblockShape controller="yet_another_industrialization:arboreous_greenhouse" />
</GameScene>

Arboreous Greenhouses are capable of growing trees or otherwise large plants.

<Recipe id="yet_another_industrialization:craft/arboreous_greenhouse" />

## Getting started

All recipes require a single sapling (or equivalent), a fluid and the appropriate multiblock soil.

Which ones? Well, different plants naturally have different needs. Some might need Water and Sand while others require Lava and Netherrack. Always check your recipe viewer for accurate info!

Trees will always yield their Logs, Leaves and their own saplings. Some trees might have additional drops like fruits, roots, etc.

## Better yields

All outputs can be doubled by replacing the fluid used with its nutrient variant. Using a **Centrifuge**, mix the following:

Water + Bone Meal = **Nutrient Water**

Lava + Nether Wart = **Nutrient Lava**

Dragon Breath + Popped Chorus Fruit = **Nutrient Dragon Breath**

Dragon Breath is annoying to collect, so consider automating it through [Impure Dragon Breath purification](../generators/dragon_egg_energy_siphon.md)!
